@@ -1,19 +1,19 @@
 /*
- * gedit-file-browser-view.h - Gedit plugin providing easy file access 
+ * gedit-file-browser-view.h - Gedit plugin providing easy file access
  * from the sidepanel
- * 
+ *
  * Copyright (C) 2006 - Jesse van den Kieboom <jesse@icecrew.nl>
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -39,17 +39,17 @@ typedef struct _GeditFileBrowserViewPrivate GeditFileBrowserViewPrivate;
 
 typedef enum {
 	GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_DOUBLE,
-	GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE	
+	GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE
 } GeditFileBrowserViewClickPolicy;
 
-struct _GeditFileBrowserView 
+struct _GeditFileBrowserView
 {
 	GtkTreeView parent;
 
 	GeditFileBrowserViewPrivate *priv;
 };
 
-struct _GeditFileBrowserViewClass 
+struct _GeditFileBrowserViewClass
 {
 	GtkTreeViewClass parent_class;
 
@@ -66,7 +66,6 @@ struct _GeditFileBrowserViewClass
 };
 
 GType		 gedit_file_browser_view_get_type			(void) G_GNUC_CONST;
-GType		 gedit_file_browser_view_register_type			(GTypeModule                     *module);
 
 GtkWidget	*gedit_file_browser_view_new				(void);
 void		 gedit_file_browser_view_set_model			(GeditFileBrowserView            *tree_view,
@@ -78,6 +77,8 @@ void		 gedit_file_browser_view_set_click_policy		(GeditFileBrowserView
 void		 gedit_file_browser_view_set_restore_expand_state	(GeditFileBrowserView            *tree_view,
 									 gboolean                         restore_expand_state);
 
+void		 _gedit_file_browser_view_register_type			(GTypeModule                     *type_module);
+
 G_END_DECLS
 
 #endif /* __GEDIT_FILE_BROWSER_VIEW_H__ */
