@@ -20,13 +20,18 @@
  * Boston, MA  02110-1301  USA
  */
 
-#include "gedit-gio-document-loader.h"
+#include "gedit-document-loader.h"
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <string.h>
 #include <sys/stat.h>
 
+/* linux/bsd has it. others such as Solaris, do not */
+#ifndef ACCESSPERMS
+#define ACCESSPERMS (S_IRWXU|S_IRWXG|S_IRWXO) 
+#endif
+
 #define DEFAULT_LOCAL_URI "/tmp/gedit-document-saver-test.txt"
 #define DEFAULT_REMOTE_URI "sftp://localhost/tmp/gedit-document-saver-test.txt"
 #define DEFAULT_CONTENT "hello world!"
@@ -146,6 +151,10 @@ mount_ready_callback (GObject      *object,
 		mount_success = TRUE;
 		g_error_free (error);
 	}
+	else if (error && error->code == G_IO_ERROR_NOT_SUPPORTED)
+	{
+		g_error_free (error);
+	}
 	else
 	{
 		g_assert_no_error (error);
@@ -195,12 +204,10 @@ test_saver (const gchar              *filename_or_uri,
             SaverTestData            *data)
 {
 	GFile *file;
-	gchar *uri;
 	GeditDocument *document;
 	gboolean existed;
 
 	document = create_document (contents);
-	gedit_document_set_newline_type (document, newline_type);
 
 	g_signal_connect (document, "saved", G_CALLBACK (complete_test_error), data);
 
@@ -214,12 +221,16 @@ test_saver (const gchar              *filename_or_uri,
 	test_completed = FALSE;
 
 	file = g_file_new_for_commandline_arg (filename_or_uri);
-	uri = g_file_get_uri (file);
 	existed = g_file_query_exists (file, NULL);
 
-	ensure_mounted (file);
+	if (!ensure_mounted (file))
+	{
+		saver_test_data_free (data);
+		return;
+	}
 
-	gedit_document_save_as (document, uri, gedit_encoding_get_utf8 (), save_flags);
+	gedit_document_save_as (document, file, gedit_encoding_get_utf8 (),
+			        newline_type, 0, save_flags);
 
 	while (!test_completed)
 	{
@@ -231,7 +242,6 @@ test_saver (const gchar              *filename_or_uri,
 		g_file_delete (file, NULL, NULL);
 	}
 
-	g_free (uri);
 	g_object_unref (file);
 
 	saver_test_data_free (data);
@@ -357,6 +367,7 @@ test_remote ()
 	            saver_test_data_new (DEFAULT_REMOTE_URI, "hello world\n\n", NULL));
 }
 
+#ifndef G_OS_WIN32
 static void
 check_permissions (GFile *file,
                    guint  permissions)
@@ -376,6 +387,7 @@ check_permissions (GFile *file,
 	                 ==,
 	                 g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_UNIX_MODE) & ACCESSPERMS);
 
+	g_object_unref (info);
 }
 
 static void
@@ -404,6 +416,12 @@ test_permissions (const gchar *uri,
 	g_file_delete (file, NULL, NULL);
 	stream = g_file_create (file, 0, NULL, &error);
 
+	if (error && error->code == G_IO_ERROR_NOT_SUPPORTED)
+	{
+		g_error_free (error);
+		return;
+	}
+
 	g_assert_no_error (error);
 
 	g_output_stream_close (G_OUTPUT_STREAM (stream), NULL, NULL);
@@ -451,6 +469,7 @@ test_local_permissions ()
 	test_permissions (DEFAULT_LOCAL_URI, 0666);
 	test_permissions (DEFAULT_LOCAL_URI, 0760);
 }
+#endif
 
 static void
 test_local_unowned_directory ()
@@ -465,15 +484,6 @@ test_local_unowned_directory ()
 	                                 NULL));
 }
 
-static void
-test_remote_permissions ()
-{
-	test_permissions (DEFAULT_REMOTE_URI, 0600);
-	test_permissions (DEFAULT_REMOTE_URI, 0660);
-	test_permissions (DEFAULT_REMOTE_URI, 0666);
-	test_permissions (DEFAULT_REMOTE_URI, 0760);
-}
-
 static void
 test_remote_unowned_directory ()
 {
@@ -487,6 +497,16 @@ test_remote_unowned_directory ()
 	                                 NULL));
 }
 
+#ifndef G_OS_WIN32
+static void
+test_remote_permissions ()
+{
+	test_permissions (DEFAULT_REMOTE_URI, 0600);
+	test_permissions (DEFAULT_REMOTE_URI, 0660);
+	test_permissions (DEFAULT_REMOTE_URI, 0666);
+	test_permissions (DEFAULT_REMOTE_URI, 0760);
+}
+
 static void
 test_unowned_group_permissions (GeditDocument *document,
                                 GError        *error,
@@ -542,6 +562,8 @@ test_remote_unowned_group ()
 	test_unowned_group (UNOWNED_GROUP_REMOTE_URI);
 }
 
+#endif
+
 static gboolean
 check_unowned_directory ()
 {
@@ -657,6 +679,7 @@ check_unowned_group ()
 		return FALSE;
 	}
 
+#ifndef G_OS_WIN32
 	if ((g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_UNIX_MODE) & ACCESSPERMS) != 0660)
 	{
 		g_object_unref (unowned);
@@ -665,6 +688,7 @@ check_unowned_group ()
 		g_object_unref (info);
 		return FALSE;
 	}
+#endif
 
 	g_object_unref (info);
 	g_object_unref (unowned);
@@ -682,8 +706,6 @@ int main (int   argc,
 	g_type_init ();
 	g_test_init (&argc, &argv, NULL);
 
-	gedit_prefs_manager_app_init ();
-
 	g_printf ("\n***\n");
 	have_unowned = check_unowned_directory ();
 	have_unowned_group = check_unowned_group ();
@@ -691,21 +713,15 @@ int main (int   argc,
 
 	g_test_add_func ("/document-saver/local", test_local);
 	g_test_add_func ("/document-saver/local-new-line", test_local_newline);
-	g_test_add_func ("/document-saver/local-permissions", test_local_permissions);
 
 	if (have_unowned)
 	{
 		g_test_add_func ("/document-saver/local-unowned-directory", test_local_unowned_directory);
 	}
 
-	if (have_unowned_group)
-	{
-		g_test_add_func ("/document-saver/local-unowned-group", test_local_unowned_group);
-	}
-
 	g_test_add_func ("/document-saver/remote", test_remote);
 	g_test_add_func ("/document-saver/remote-new-line", test_remote_newline);
-	g_test_add_func ("/document-saver/remote-permissions", test_remote_permissions);
+	
 
 	if (have_unowned)
 	{
@@ -718,5 +734,17 @@ int main (int   argc,
 		/* g_test_add_func ("/document-saver/remote-unowned-group", test_remote_unowned_group); */
 	}
 
+#ifndef G_OS_WIN32
+	g_test_add_func ("/document-saver/local-permissions", test_local_permissions);
+
+	if (have_unowned_group)
+	{
+		g_test_add_func ("/document-saver/local-unowned-group", test_local_unowned_group);
+	}
+
+	g_test_add_func ("/document-saver/remote-permissions", test_remote_permissions);
+#endif
+
 	return g_test_run ();
 }
+/* ex:ts=8:noet: */
